# Pyepub

Pyepub is a module for reading and writing EPUB files.

## Documentation

For a quick tutorial, look at [Quickstart](docs/quickstart.md).

## Vs Ebooklib

There is another python EPUB package,
[ebooklib](https://github.com/aerkalov/ebooklib). I believe pyepub's interface
is simpler than ebooklib's; also, pyepub supports reading an EPUB, changing the
`Publication` object directly, and writing it back to a file. But ebooklib is a
good library, and if pyepub does not suit you, you might want to try it instead.
